#!/bin/bash

#Company:       PowerCraft Technology
#Author:        Copyright Jelle de Jong <jelledejong@powercraft.nl>
#Note:          Please send me an email if you enhanced this script
#Version:       0.0.2
#Date:          19-01-2007 / 19-01-2008
#System:        Xubuntu 7.10
#Information:   man unrar, man par2, man file
#Category       Thunar scripts
#Name:          Backup File(s)
#Description:   Backup selected items
#Command:       xfce4-terminal --disable-server --hide-toolbars --execute ~/.scripts/thunar/file-backup.sh %F
#Patterns:      *
#Directories:   True
#Audio Files:   True
#Image Files:   True
#Text Files:    True
#Video Files:   True
#Other Files:   True

# Did the script work for you?
# Yes
# Yes, but with some errors
# Yes, but I had to change some things
# Not at all

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301, USA.

location="/media/disk/backup/"
location+=$(date +%Y-%m-%d-%H:%M:%S)

cecho()
{
    if [ "$1" = "black" ]; then
        echo -ne "\E[30m"
    elif [ "$1" = "red" ]; then
        echo -ne "\E[31m"
    elif [ "$1" = "green" ]; then
        echo -ne "\E[32m"
    elif [ "$1" = "yellow" ]; then
        echo -ne "\E[33m"
    elif [ "$1" = "blue" ]; then
        echo -ne "\E[34m"
    elif [ "$1" = "magenta" ]; then
        echo -ne "\E[35m"
    elif [ "$1" = "cyan" ]; then
        echo -ne "\E[36m"
    fi

    echo $2 $3
    tput sgr0
}

cecho "green" "processing:"
for I in "$@"
do
    cecho "blue" "$I"
done

cecho "green" "backup location:"
cecho "blue" "$location"

echo -n "are you sure you want to continue [Y/n]? "
read input
if [ "$input" = "n" ]
then
    exit 0
fi

cecho "blue" "---------------"

for I in "$@"
do
    cecho "green" "starting: "

    filename="$I";  filename=${filename##*/}; filename="${filename%.*}"

    unset permission
    if [ ! -w "$I" ]
    then
        permission="sudo"
    fi

    if [ ! -d "$location" ]
    then
        cecho "blue" "creating the backup location"
        $permission mkdir -v -m 0777 -p "$location"
    fi

    if [ -d "$location" ]
    then
        cecho "magenta" -n "backup item from:"
        echo "$I"
        cecho "magenta" -n "backup item to:"
        echo "$location/$filename.tar"
        cd "$location"
        $permission tar --create \
            --preserve-permissions \
            --preserve-order \
            --absolute-names \
            --force-local \
            --totals \
            --verify \
            --file="$filename.tar" \
            "$I"
    fi

    if [ $? -eq 1 ]
    then
        cecho "red" "error processing $filename, continue after 15 seconds"
        sleep 15
        continue
    fi

    cecho "green" "completed:"
    cecho "blue" "---------------"
done

cecho "green" -n "done, do you want to exit [Y/n]? "
read input
if [ ! "$input" = "n" ]
then
    exit
fi

cecho "green" "done, closing after 3 seconds"
sleep 3
exit

#filename=${I##*/}
#foo=/media/usbdisk/bac.kup/foo.tar.gz; foo=${foo##*/}; [[ $foo = *.tar.gz ]] && echo $foo || echo ${foo%.*}
#mkdir "2007-01-18 13:28"; cd "2007-01-18 13:28"; touch "2007-01-18 13:28.txt"; cd ..; filename="2007-01-18 13:28"; tar --create --preserve-permissions --preserve-order --absolute-names --force-local --totals --verify --file="$filename.tar" "$filename"

