#!/bin/bash

#Company:       PowerCraft Technology
#Author:        Copyright Jelle de Jong <info@powercraft.nl>
#Note:          Please send me an email if you enhanced this script
#Version:       0.0.4
#Date:          02-09-2006 / 01-04-07 / 16-11-07 / 01-01-08
#System:        Xubuntu 7.10
#Information:   man mount, man mkdir, man umount
#Category       Thunar scripts
#Name:          (U)mount image
#Description:   Create a directory with the imagename and mount or umount it there
#Command:       xfce4-terminal --disable-server --hide-toolbars --execute ~/.scripts/thunar/u-mount-image.sh %F
#Patterns:      *.iso; *.img; *.nrg; *.mds; *.ISO;
#Other Files:   True

# Did the script work for you?
# Yes
# Yes, but with some errors
# Yes, but I had to change some things
# Not at all

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301, USA.

cecho()
{
    if [ "$1" = "black" ]; then
        echo -ne "\E[30m"
    elif [ "$1" = "red" ]; then
        echo -ne "\E[31m"
    elif [ "$1" = "green" ]; then
        echo -ne "\E[32m"
    elif [ "$1" = "yellow" ]; then
        echo -ne "\E[33m"
    elif [ "$1" = "blue" ]; then
        echo -ne "\E[34m"
    elif [ "$1" = "magenta" ]; then
        echo -ne "\E[35m"
    elif [ "$1" = "cyan" ]; then
        echo -ne "\E[36m"
    fi

    echo $2 $3
    tput sgr0
}

echo "processing file(s): "
for I in "$@"
do
    cecho "blue" "$I"
done

echo "enter current working directory: "
cecho "blue" "$PWD"
cd "$PWD"

for I in "$@"
do
    echo "starting with: "
    cecho "blue" "$I"

    filetype=$(file -b "$I" | cut -f 1 -d "'")
    imagename=$(file -b "$I" | cut -f 2 -d "'" | cut -f 1 -d " ")
    dirname=${I%/*}
    file=${I}
    filename=${I##*/}; filename=${filename%.*}
    extension=${I##*.}

    echo "file type is: "
    cecho "blue" "$filetype"

    if [ -n "$filename" ] && [ ! -n "$imagename" ]
    then
        imagename+=ISO
    fi

    echo "image name is: "
    cecho "blue" "$imagename"

    #sudo mount -f "$I" "$imagename" 2> status.txt
    #status=$(grep --count --ignore-case "already mounted"  status.txt)

    status=$(sudo mount -f "$I" "$imagename" 2>&1 | grep --count --ignore-case "already mounted")

    completed=0

    if [ "$imagename" = "$filename" ]
    then
        imagename+=_MOUNT
    fi

    if [ "$status" != 0 ]
    then
        echo "status: "
        cecho "blue" "$status"

        cecho "red" ""$imagename" already mounted"

        cecho "green" "choose a option"
        cecho "blue" "[1] umount image (used after 4 seconds)"
        cecho "blue" "[2] remount image"
        cecho "blue" "[3] exit"
        option=1
        read -t4 -p "pleae make your slection within 4 seconds, and press enter: " option
        echo ""

        if [ "$option" = "1" ]
        then
            cecho "blue" "umount image"
            sudo umount -f "$imagename"
            cecho "blue" "remove directory if empty, excists and where the image was mounted"
            if [ -e "$imagename" ] && [ ! "$(ls -A $imagename)" ]
            then
                rm -R "$imagename"
            fi
            completed=1
        fi

        if [ "$option" = "2" ]
        then
            cecho "blue" "umount any previous mounts"
            sudo umount -f "$imagename"
        fi

        if [ "$option" = "3" ]
        then
            cecho "green" "exit after 3 seconds"
            sleep 3
            exit
        fi
    fi


    if [ "ReiserFS V3.6 block size 4096 (mounted or unclean) num blocks 1311296 r5 hash" -a $completed -eq 0 ]
    then
        #create directory to mount the image
        [ ! -e "$imagename" ] && mkdir "$imagename"
        #mount the image to the created directory
        sudo mount -o loop "$I" "$imagename"
        completed=1
    fi

    if [ "$filetype" = "ISO 9660 CD-ROM filesystem data " -a $completed -eq 0 ]
    then
        #create directory to mount the image
        [ ! -e "$imagename" ] && mkdir "$imagename"
        #mount the image to the created directory
        sudo mount -t iso9660 -o loop "$I" "$imagename"
        completed=1
    fi

    if [ ! $completed -eq 1 ]
    then
        cecho "red" "error nothing completed, exit in 30 seconds without success"
        sleep 30
        exit 1
    fi

    if [ $? -eq 1 ]
    then
        cecho "red" "error mounting, exit in 30 seconds without success"
        sleep 30
        exit 1
    fi

    echo "completed with: "
    cecho "green" "$I"
    cecho "blue" "---------------"
done

echo "done, closing after 3 seconds"
sleep 3
exit
